import fs from 'fs-extra';

/**
 * Creates a new Date object with the specified hour and minute.
 *
 * @param {number} hours - The hour to set for the new Date
 * @param {number} minutes - The minute to set for the new Date
 * @return {Date} The new Date object with the specified hour and minute
 *
 * @example
 * // creates a Date object with the hour 12 and minute 30
 *
 * // if current time is 12:30
 *
 * const newDate = createDate(12, 30);
 * console.log(newDate);
 * @result Wed Dec 31 2022 12:30:00
 */
declare const createDate: (hours: number, minutes: number) => Date;
/**
 * Creates a new Date object that represents a specific date and time in the future, based on the current date and time.
 *
 * @param {number} offsetInDays - The number of days to offset from the current date and time.
 * @return {Date} - The new Date object representing the future date and time.
 */
declare const createDateFromNowWithOffset: (offsetInDays: number) => Date;

/**
 * Deletes the specified directory if it exists.
 *
 * @param {string} directoryPath - The path of the directory to be deleted
 * @return {boolean} Returns true if the directory is successfully deleted, otherwise false
 */
declare const fsDeleteDirectory: (directoryPath: string) => Promise<boolean>;
/**
 * Deletes a file at the specified filePath.
 *
 * @param {string} filePath - The path of the file to be deleted.
 * @return {Promise<boolean>} A Promise that resolves to true if the file is successfully deleted.
 */
declare const fsDeleteFile: (filePath: string) => Promise<boolean>;

type DownloadFileOptions = {
    url: string;
    fileName?: string;
    directoryPath: string;
    limit?: {
        minBytes?: number;
        maxBytes?: number;
    };
};
interface DownloadFile {
    path: string;
    size: number;
    sizeInMB: string;
    fileType: string;
    fileTypeExt: string;
    fileName: string;
    url: string;
    createdAt: Date;
}
declare const downloadFileFromUrl: ({ url, fileName, directoryPath, limit, }: DownloadFileOptions) => Promise<DownloadFile>;

type JSONTypes = Object | Array<any> | Object[] | Array<Object> | string;
/**
 * Reads a JSON file from the given file path and returns its content as a parsed JSON object.
 *
 * @param {string} filePath - The path of the JSON file to be read.
 * @return {Promise<JSONTypes>} A promise that resolves to the parsed JSON object.
 * @throws {Error} If there was an error reading the file or parsing its content.
 */
declare const readJSONFile: (filePath: string) => Promise<JSONTypes>;
/**
 * Write JSON data to a file.
 *
 * @param {string} filePath - the path to the file
 * @param {JSONTypes} jsonData - the JSON data to be written
 * @param {fs.JsonWriteOptions} [options] - the options for writing JSON
 * @return {Promise<boolean>} whether the JSON data was successfully written to the file
 */
declare const writeJsonToFile: (filePath: string, jsonData: JSONTypes, options?: fs.JsonWriteOptions) => Promise<boolean>;

/**
 * Writes the given content to a file in the specified directory with the given file name.
 *
 * @example
 * const filePath = await writeToFile('/path/to/directory', 'content', 'filename.txt');
 * console.log(filePath);
 * // '/path/to/directory/filename.txt'
 *
 * If the directory does not exist, it will be created.
 * If the file already exists, it will be overwritten.
 * If the directory or the file cannot be created, an error will be thrown.
 *
 * @param {string} directory - The directory where the file will be written.
 * @param {string | Buffer | Uint8Array} content - The content to be written to the file.
 * @param {string} fileName - The name of the file.
 * @return {Promise<string>} - A promise that resolves to the file path where the content was written.
 */
declare const writeToFile: (directory: string, content: string | Buffer | Uint8Array, fileName: string) => Promise<string>;

declare const index$2_createDate: typeof createDate;
declare const index$2_createDateFromNowWithOffset: typeof createDateFromNowWithOffset;
declare const index$2_downloadFileFromUrl: typeof downloadFileFromUrl;
declare const index$2_fsDeleteDirectory: typeof fsDeleteDirectory;
declare const index$2_fsDeleteFile: typeof fsDeleteFile;
declare namespace index$2 {
  export { index$2_createDate as createDate, index$2_createDateFromNowWithOffset as createDateFromNowWithOffset, index$2_downloadFileFromUrl as downloadFileFromUrl, index$2_fsDeleteDirectory as fsDeleteDirectory, index$2_fsDeleteFile as fsDeleteFile, readJSONFile as fsReadJSONFile, writeJsonToFile as fsWriteJsonToFile, writeToFile as fsWriteToFile };
}

/**
 * Checks if a given string is a valid IPv4 address.
 *
 * @param {string|null|undefined} ipAddress - The IP address to validate.
 * @returns {boolean} True if the IP address is valid, false otherwise.
 * @throws {TypeError} Throws a TypeError if ipAddress is not a string.
 */
declare const isValidIpAddress: (ipAddress: string | null | undefined) => boolean;

/**
 * Checks if a given string is a valid JSON.
 *
 * @param {string} json - The string to be checked.
 * @returns {boolean} - Returns `true` if the string is valid JSON, `false` otherwise.
 */
declare const isValidJson: (json: string) => boolean;

/**
 * Check if a given string is a valid URL.
 * @param url The string to be checked.
 * @param allowedProtocols An optional array of allowed protocols.
 * @returns {boolean} Returns true if the url is a valid URL, false otherwise.
 * @throws {TypeError} Throws a TypeError if url is not a string.
 */
declare const isValidUrl: (url: string, allowedProtocols?: string[]) => boolean;

declare const index$1_isValidIpAddress: typeof isValidIpAddress;
declare const index$1_isValidJson: typeof isValidJson;
declare const index$1_isValidUrl: typeof isValidUrl;
declare namespace index$1 {
  export { index$1_isValidIpAddress as isValidIpAddress, index$1_isValidJson as isValidJson, index$1_isValidUrl as isValidUrl };
}

declare const bytesToMb: (bytes: number) => number;

/**
 * Convert an epoch time (in seconds) to a Date object.
 *
 * @param epoch - The epoch time to convert.
 * @returns {Date} - The converted Date object.
 * @throws {Error} - If epoch is not a valid number.
 */
declare const epochToDate: (epoch: number) => Date;

declare const index_bytesToMb: typeof bytesToMb;
declare const index_epochToDate: typeof epochToDate;
declare namespace index {
  export { index_bytesToMb as bytesToMb, index_epochToDate as epochToDate };
}

export { index as convert, index$1 as isValid, index$2 as util };
